/*
 * Copyright: (C) 2008 Bruce W. Forsberg
 *
 *   This library is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU Lesser General Public
 *   License as published by the Free Software Foundation; either
 *   version 2.1 of the License, or any later version.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *   Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 *
 *   Bruce Forsberg  bruce.forsberg@gmail.com
 *
 */
#ifndef TRIP_TAB_H
#define TRIP_TAB_H


#include <gtk/gtk.h>

extern void trip_tab_layout(GtkWidget *window);
extern void trip_tab_load_car(char * car);
extern GtkWidget *trip_tab_get_car_selector();
extern int  trip_tab_get_car_inserted();
extern void trip_tab_update_car_combo_box(int);
extern void trip_init();
extern void trip_set_fields(char *, char *, char *, char *, char *, char *, char *);
extern void trip_tab_fullscreen(int fullscreen);
#endif
